@@ -38,7 +38,7 @@ void EventViews::setResourceColor(const Akonadi::Collection &coll, const QColor
 
     // Save the color in akonadi (so the resource can even save it server-side)
     Akonadi::Collection collection = coll;
-    auto *colorAttr = collection.attribute<Akonadi::CollectionColorAttribute>(Akonadi::Collection::AddIfMissing);
+    auto colorAttr = collection.attribute<Akonadi::CollectionColorAttribute>(Akonadi::Collection::AddIfMissing);
     colorAttr->setColor(color);
     auto job = new Akonadi::CollectionModifyJob(collection, nullptr);
     QObject::connect(job, &Akonadi::CollectionModifyJob::result, [=]() {
@@ -64,7 +64,7 @@ QColor EventViews::resourceColor(const Akonadi::Collection &coll, const PrefsPtr
     }
     // Color stored in akonadi
     if (coll.hasAttribute<Akonadi::CollectionColorAttribute>()) {
-        const auto *colorAttr = coll.attribute<Akonadi::CollectionColorAttribute>();
+        const auto colorAttr = coll.attribute<Akonadi::CollectionColorAttribute>();
         if (colorAttr && colorAttr->color().isValid()) {
             return colorAttr->color();
         }
@@ -81,7 +81,7 @@ QColor EventViews::resourceColor(const Akonadi::Item &item, const PrefsPtr &pref
     return resourceColor(item.parentCollection(), preferences);
 }
 
-int EventViews::yearDiff(const QDate &start, const QDate &end)
+int EventViews::yearDiff(QDate start, QDate end)
 {
     return end.year() - start.year();
 }
