@@ -158,14 +158,14 @@ void MonthItem::moveBy(int offsetToPreviousDate)
 
 void MonthItem::updateGeometry()
 {
-    for (MonthGraphicsItem *item : qAsConst(mMonthGraphicsItemList)) {
+    for (MonthGraphicsItem *item : std::as_const(mMonthGraphicsItemList)) {
         item->updateGeometry();
     }
 }
 
 void MonthItem::setZValue(qreal z)
 {
-    for (MonthGraphicsItem *item : qAsConst(mMonthGraphicsItemList)) {
+    for (MonthGraphicsItem *item : std::as_const(mMonthGraphicsItemList)) {
         item->setZValue(z);
     }
 }
@@ -193,13 +193,8 @@ int MonthItem::daySpan() const
     if (isMoving() || isResizing()) {
         return mOverrideDaySpan;
     }
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QDateTime start(startDate());
-    QDateTime end(endDate());
-#else
     QDateTime start(startDate().startOfDay());
     QDateTime end(endDate().startOfDay());
-#endif
 
     if (start.isValid() && end.isValid()) {
         return start.daysTo(end);
@@ -284,7 +279,7 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
                                        const Akonadi::ETMCalendar::Ptr &calendar,
                                        const Akonadi::Item &aitem,
                                        const KCalendarCore::Incidence::Ptr &incidence,
-                                       const QDate &recurStartDate)
+                                       QDate recurStartDate)
     : MonthItem(monthScene)
     , mCalendar(calendar)
     , mIncidence(incidence)
@@ -449,7 +444,7 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
     }
 }
 
-void IncidenceMonthItem::updateSelection(const Akonadi::Item &incidence, const QDate &date)
+void IncidenceMonthItem::updateSelection(const Akonadi::Item &incidence, QDate date)
 {
     Q_UNUSED(date)
     setSelected(incidence == akonadiItem());
@@ -674,7 +669,7 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
 
 //-----------------------------------------------------------------
 // HOLIDAYMONTHITEM
-HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, const QDate &date, const QString &name)
+HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, QDate date, const QString &name)
     : MonthItem(monthScene)
     , mDate(date)
     , mName(name)
