@@ -20,8 +20,8 @@
 
 #include <KCalendarCore/CalFilter>
 
-#include <QLineEdit>
 #include <KLocalizedString>
+#include <QLineEdit>
 
 #include <QHBoxLayout>
 
@@ -29,16 +29,13 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
     : QWidget(parent)
     , mCalendar(calendar)
 {
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     // no special margin because it is added by the view
     layout->setContentsMargins(0, 0, 0, 0);
 
     mSearchLine = new QLineEdit(this);
-    mSearchLine->setToolTip(
-        i18nc("@info:tooltip", "Filter on matching summaries"));
-    mSearchLine->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Enter text here to filter the to-dos that are shown by matching summaries."));
+    mSearchLine->setToolTip(i18nc("@info:tooltip", "Filter on matching summaries"));
+    mSearchLine->setWhatsThis(i18nc("@info:whatsthis", "Enter text here to filter the to-dos that are shown by matching summaries."));
     mSearchLine->setPlaceholderText(i18nc("@label in QuickSearchLine", "Search Summaries..."));
     mSearchLine->setClearButtonEnabled(true);
     connect(mSearchLine, &QLineEdit::textChanged, this, &TodoViewQuickSearch::searchTextChanged);
@@ -47,19 +44,16 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
 
     mCategoryCombo = new Akonadi::TagSelectionComboBox(this);
     mCategoryCombo->setCheckable(true);
-    mCategoryCombo->setToolTip(
-        i18nc("@info:tooltip", "Filter on these categories"));
-    mCategoryCombo->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Use this combobox to filter the to-dos that are shown by "
-              "a list of selected categories."));
-    const QString defaultText = i18nc("@item:inlistbox", "Select Categories");
+    mCategoryCombo->setToolTip(i18nc("@info:tooltip", "Filter on these tags"));
+    mCategoryCombo->setWhatsThis(i18nc("@info:whatsthis",
+                                       "Use this combobox to filter the to-dos that are shown by "
+                                       "a list of selected tags."));
+    const QString defaultText = i18nc("@item:inlistbox", "Select Tags");
     mCategoryCombo->lineEdit()->setPlaceholderText(defaultText);
 
-    connect(mCategoryCombo, &Akonadi::TagSelectionComboBox::selectionChanged,
-            this, [this]() {
-                Q_EMIT filterCategoryChanged(mCategoryCombo->selectionNames());
-            });
+    connect(mCategoryCombo, &Akonadi::TagSelectionComboBox::selectionChanged, this, [this]() {
+        Q_EMIT filterCategoryChanged(mCategoryCombo->selectionNames());
+    });
 
     layout->addWidget(mCategoryCombo, 1);
 
@@ -71,26 +65,21 @@ TodoViewQuickSearch::TodoViewQuickSearch(const Akonadi::ETMCalendar::Ptr &calend
         const int currentPreferedWidth = mCategoryCombo->lineEdit()->sizeHint().width();
 
         // Calculate a nice size for "Select Categories"
-        const int newPreferedWidth = currentPreferedWidth
-                                     -fm.boundingRect(QLatin1Char('x')).width() * 17
-                                     +fm.boundingRect(defaultText).width();
+        const int newPreferedWidth = currentPreferedWidth - fm.boundingRect(QLatin1Char('x')).width() * 17 + fm.boundingRect(defaultText).width();
 
         const int pixelsToAdd = newPreferedWidth - mCategoryCombo->lineEdit()->width();
         mCategoryCombo->setMinimumWidth(mCategoryCombo->width() + pixelsToAdd);
     }
 
     mPriorityCombo = new KPIM::KCheckComboBox(this);
-    mPriorityCombo->setToolTip(
-        i18nc("@info:tooltip", "Filter on these priorities"));
-    mPriorityCombo->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Use this combobox to filter the to-dos that are shown by "
-              "a list of selected priorities."));
+    mPriorityCombo->setToolTip(i18nc("@info:tooltip", "Filter on these priorities"));
+    mPriorityCombo->setWhatsThis(i18nc("@info:whatsthis",
+                                       "Use this combobox to filter the to-dos that are shown by "
+                                       "a list of selected priorities."));
     mPriorityCombo->lineEdit()->setPlaceholderText(i18nc("@item:inlistbox", "Select Priority"));
-    connect(mPriorityCombo, &KPIM::KCheckComboBox::checkedItemsChanged,
-            this, [this]() {
-                Q_EMIT filterPriorityChanged(mPriorityCombo->checkedItems(Qt::UserRole));
-            });
+    connect(mPriorityCombo, &KPIM::KCheckComboBox::checkedItemsChanged, this, [this]() {
+        Q_EMIT filterPriorityChanged(mPriorityCombo->checkedItems(Qt::UserRole));
+    });
 
     layout->addWidget(mPriorityCombo, 1);
     fillPriorities();
@@ -127,4 +116,3 @@ void TodoViewQuickSearch::fillPriorities()
     // TODO: Using the same method as for categories to fill mPriorityCombo
     CalendarSupport::CategoryHierarchyReaderQComboBox(mPriorityCombo).read(priorityValues);
 }
-
