@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARVIEWS_TODOVIEWSORTFILTERPROXYMODEL_H
-#define CALENDARVIEWS_TODOVIEWSORTFILTERPROXYMODEL_H
+#pragma once
 
 #include "prefs.h"
 
@@ -52,4 +51,3 @@ private:
     EventViews::PrefsPtr mPreferences;
 };
 
-#endif
